==> opensaml-soap-impl-3.4.4-sources.jar: org/opensaml/soap/wssecurity/impl/EncodedStringMarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.soap.wssecurity.EncodedString;
import org.w3c.dom.Element;

import com.google.common.base.Strings;

/**
 * Marshaller for instances of {@link EncodedString}.
 */
public class EncodedStringMarshaller extends AttributedStringMarshaller {

    /** {@inheritDoc} */
    protected void marshallAttributes(final XMLObject xmlObject, final Element domElement) throws MarshallingException {
        final EncodedString encodedString = (EncodedString) xmlObject;
        if (!Strings.isNullOrEmpty(encodedString.getEncodingType())){
            domElement.setAttributeNS(null, EncodedString.ENCODING_TYPE_ATTRIB_NAME, encodedString.getEncodingType());
        }
        super.marshallAttributes(xmlObject, domElement);
    }
    
}

==> opensaml-soap-impl-5.1.4-sources.jar: org/opensaml/soap/wssecurity/impl/EncodedStringMarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import javax.annotation.Nonnull;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.soap.wssecurity.EncodedString;
import org.w3c.dom.Element;

import com.google.common.base.Strings;

/**
 * Marshaller for instances of {@link EncodedString}.
 */
public class EncodedStringMarshaller extends AttributedStringMarshaller {

    /** {@inheritDoc} */
    protected void marshallAttributes(@Nonnull final XMLObject xmlObject, @Nonnull final Element domElement)
            throws MarshallingException {
        final EncodedString encodedString = (EncodedString) xmlObject;
        if (!Strings.isNullOrEmpty(encodedString.getEncodingType())){
            domElement.setAttributeNS(null, EncodedString.ENCODING_TYPE_ATTRIB_NAME, encodedString.getEncodingType());
        }
        super.marshallAttributes(xmlObject, domElement);
    }
    
}
